@@ -134,39 +134,32 @@ def combine_shapefile_parts(
                     zip_file.write(chunk)
 
 
-def _validate_and_fix_multipoint_coordinates(shape: dict) -> dict:
+def _parse_geometry_safely(geometry, geom_format: GeometryFormat) -> dict | None:
     """
-    Validate and fix MultiPoint coordinates to ensure they are properly formatted.
+    Safely parse geometry data from WKT or GeoJSON format.
 
     Args:
-        shape: GeoJSON-like shape dictionary
+        geometry: Geometry data in WKT or GeoJSON format (string or dict)
+        geom_format: Format of the geometry data
 
     Returns:
-        dict: Fixed shape dictionary with valid coordinates
+        dict: Parsed geometry dictionary, or None if parsing fails
     """
-    if shape["type"] == "MultiPoint":
-        valid_coordinates = []
-        for coord in shape["coordinates"]:
-            # Ensure each coordinate is a proper [x, y] pair
-            if isinstance(coord, (list, tuple)) and len(coord) >= 2:
-                valid_coordinates.append([float(coord[0]), float(coord[1])])
-            elif isinstance(coord, (int, float)):
-                # Skip malformed single-value coordinates
-                continue
-            else:
-                # Skip any other malformed coordinates
-                continue
+    if geometry is None:
+        return None
 
-        # Only proceed if we have valid coordinates
-        if valid_coordinates:
-            shape = shape.copy()
-            shape["coordinates"] = valid_coordinates
-            return shape
+    try:
+        if geom_format == GeometryFormat.WKT:
+            if isinstance(geometry, str):
+                return wkt.loads(geometry)
+            return geometry  # Already parsed
         else:
-            # Return a null geometry if no valid coordinates
-            return {"type": "Point", "coordinates": []}
-
-    return shape
+            if isinstance(geometry, str):
+                return json.loads(geometry)
+            return geometry  # Already parsed
+    except (json.JSONDecodeError, TypeError, ValueError):
+        # Return None for any parsing errors - this will result in null geometry
+        return None
 
 
 def _determine_shapetype_from_geometry(geometry, geom_format: GeometryFormat) -> int:
@@ -180,21 +173,11 @@ def _determine_shapetype_from_geometry(geometry, geom_format: GeometryFormat) ->
     Returns:
         int: pyshp shapetype constant
     """
-    if geometry is None:
+    parsed_geometry = _parse_geometry_safely(geometry, geom_format)
+    if parsed_geometry is None:
         return pyshp.NULL
 
-    try:
-        if geom_format == GeometryFormat.WKT:
-            if isinstance(geometry, str):
-                geometry = wkt.loads(geometry)
-        else:
-            if isinstance(geometry, str):
-                geometry = json.loads(geometry)
-    except (json.JSONDecodeError, TypeError, ValueError):
-        # Return NULL for malformed geometry
-        return pyshp.NULL
-
-    geom_type = geometry.get("type", "").upper()
+    geom_type = parsed_geometry.get("type", "").upper()
 
     if geom_type in ("POINT", "MULTIPOINT"):
         return pyshp.MULTIPOINT
@@ -256,16 +239,7 @@ def export_to_shapefile_from_rows(
                     shpfile.field(field.name, "C")
         for row in all_rows:
             geometry = row[geom_key]
-            if geometry is None:
-                shape = None
-            elif geom_format == GeometryFormat.WKT:
-                shape = wkt.loads(geometry)
-            else:
-                try:
-                    shape = json.loads(geometry)
-                except (json.JSONDecodeError, TypeError):
-                    # Skip rows with invalid geometry data
-                    continue
+            shape = _parse_geometry_safely(geometry, geom_format)
 
             # Check if geometry type matches the determined shapetype
             if shape is not None:
@@ -285,18 +259,10 @@ def export_to_shapefile_from_rows(
             shpfile.record(**record)
             if shape is not None:
                 if shape["type"] == "Point":
-                    # Always use multipoint instead of point in shapefile output
+                    # Shapefile distinguishes between single and multi points
                     shape["type"] = "Multi" + shape["type"]
                     shape["coordinates"] = [shape["coordinates"]]
-
-                # Validate and fix MultiPoint coordinates before passing to pyshp
-                shape = _validate_and_fix_multipoint_coordinates(shape)
-
-                # Skip empty geometries
-                if shape["coordinates"]:
-                    shpfile.shape(shape)
-                else:
-                    shpfile.null()
+                shpfile.shape(shape)
             else:
                 shpfile.null()
     # Write projection file
@@ -325,12 +291,7 @@ def export_to_geojson_from_rows(
     geojson = {"type": "FeatureCollection", "features": []}
     for row in rows:
         geometry = row[geom_key]
-        if geom_format == GeometryFormat.WKT:
-            if isinstance(geometry, str):
-                geometry = wkt.loads(geometry)
-        else:
-            if isinstance(geometry, str):
-                geometry = json.loads(geometry)
+        geometry = _parse_geometry_safely(geometry, geom_format)
         properties = {}
         for field in schema:
             if field.name == geom_key:
@@ -374,13 +335,11 @@ def export_to_csv_from_rows(
     writer.writeheader()
     for row in rows:
         geometry = row[geom_key]
-        if geom_format == GeometryFormat.GEOJSON:
-            if isinstance(geometry, str):
-                geometry = json.loads(geometry)
-            geometry = wkt.dumps(geometry)
+        parsed_geometry = _parse_geometry_safely(geometry, geom_format)
+        if parsed_geometry is not None:
+            geometry = wkt.dumps(parsed_geometry)
         else:
-            if not isinstance(geometry, str):
-                geometry = wkt.dumps(geometry)
+            geometry = None  # Will result in empty geometry field
         csv_row = {}
         for field in schema:
             if field.name == geom_key:
